import request from '@/utils/request'

// 查询引江济太站点列表
export function listStation(query) {
  return request({
    url: '/yjjt/station/list',
    method: 'get',
    params: query
  })
}

// 查询引江济太站点详细
export function getStation(stcd, year) {
  return request({
    url: '/yjjt/station/detail',
    method: 'get',
    params: { stcd, year }
  })
}

// 新增引江济太站点
export function addStation(data) {
  return request({
    url: '/yjjt/station',
    method: 'post',
    data: data
  })
}

// 修改引江济太站点
export function updateStation(data) {
  return request({
    url: '/yjjt/station',
    method: 'put',
    data: data
  })
}

// 删除引江济太站点
export function delStation(data) {
  return request({
    url: '/yjjt/station/delete',
    method: 'delete',
    data: data
  })
}

// 批量删除引江济太站点
export function delStationBatch(data) {
  return request({
    url: '/yjjt/station/delete/batch',
    method: 'delete',
    data: data
  })
}

// 导出引江济太站点
export function exportStation(query) {
  return request({
    url: '/yjjt/station/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}

// 导入引江济太站点
export function importStation(data) {
  return request({
    url: '/yjjt/station/import',
    method: 'post',
    data: data
  })
}

// 下载引江济太站点导入模板
export function importStationTemplate() {
  return request({
    url: '/yjjt/station/importTemplate',
    method: 'get',
    responseType: 'blob'
  })
}
